translate.lang.sv.sv

Package translate :: Package lang :: Module sv :: Class sv |
[hide private]
[frames] | no frames]

# Class sv

source code

This class represents Swedish.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `common.Common`: `alter_length`, `capsstart`, `character_iter`, `characters`, `length_difference`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| validaccel = ``u'``abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTU``...`` Characters that can be used as accelerators (access keys) i.e.
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `ignoretests`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `puncdict`, `punctuation`, `quotes`, `rtlpunc`, `sentenceend`, `sentencere`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### validaccel Characters that can be used as accelerators (access keys) i.e. Alt+X where X is the accelerator. These can include combining diacritics as long as they are accessible from the users keyboard in a single keystroke, but normally they would be at least precomposed characters. All characters, lower and upper, are included in the list. Value:
      u'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890åäöÅÄÖ
      '